dialect library

API for implementation of custom SQL dialects for package:typed_sql.

You should only ever need to import this library, if you are implementing a custom SqlDialect.

Warning

This interface is NOT stable yet, while subclasses of SqlDialect is possible outside package:typed_sql, newer versions of this package may add new methods (remove existing) without a major version bump!

Classes

AvgExpression
BinaryOperationExpression<T, R>
CastExpression<T, R>
CompositeQueryClause
CountAllExpression
CreateTableStatement
CurrentTimestampExpression
CustomDataType<T extends Object?> Schema definition Custom data types
Interface to be implemented by custom types that can be stored in a Row for automatic (de)-serialization.
DeleteStatement
DistinctClause
EncodedCustomDataTypeExpression<S, T extends CustomDataType<S>>
ExceptClause
ExistsExpression
Expr<T extends Object?> Inserting rows Writing queries Update and delete
A representation of an SQL expression with type T.
ExpressionBlobConcat
ExpressionBlobDecodeUtf8
ExpressionBlobLength
ExpressionBlobSublist
ExpressionBlobToHex
ExpressionBoolAnd
ExpressionBoolNot
ExpressionBoolOr
ExpressionContext
Interface implemented by object with-in which expressions may exist.
ExpressionEquals<T extends Object>
SQL Expression using =.
ExpressionGreaterThan<T extends Object>
SQL Expression using >.
ExpressionGreaterThanOrEqual<T extends Object>
SQL Expression using >=.
ExpressionIsNotDistinctFrom<T extends Object>
SQL Expression using IS NOT DISTINCT FROM.
ExpressionJsonExtract
Extract a raw TEXT representation from a ExpressionJsonRef into a JsonValue
ExpressionJsonRef
Base class for JSON expressions reference a property or index in a JsonValue.
ExpressionJsonRefIndex
Accessing a key in a JSON object, using value -> index in SQL.
ExpressionJsonRefKey
Accessing a key in a JSON object, using value -> 'key' in SQL.
ExpressionJsonRefRoot
The root of a JSON reference.
ExpressionLessThan<T extends Object>
SQL Expression using <.
ExpressionLessThanOrEqual<T extends Object>
SQL Expression using <=.
ExpressionNumAdd<T extends num>
ExpressionNumDivide<T extends num>
ExpressionNumMultiply<T extends num>
ExpressionNumSubtract<T extends num>
ExpressionResolver<T>
ExpressionStringContains
ExpressionStringEndsWith
ExpressionStringIsEmpty
ExpressionStringLength
ExpressionStringLike
ExpressionStringStartsWith
ExpressionStringToLowerCase
ExpressionStringToUpperCase
FieldExpression<T>
FromClause
GroupByClause
InsertStatement
IntersectClause
JoinClause
JsonValue
Wraps a JSON value.
LimitClause
Literal<T>
MaxExpression<T extends Comparable>
MinExpression<T extends Comparable>
NotNullExpression<T>
OffsetClause
OrderByClause
OrElseExpression<T>
QueryClause
Row Schema definition
Marker class which all row classes must extend.
RowExpression<T extends Row>
SelectClause
SelectFromClause
SelectStatement
SqlDialect
Interface for implementation of custom SQL dialects for package:typed_sql.
SqlStatement
SubQueryExpression<T>
SumExpression<T extends num>
TableClause
UnionAllClause
UnionClause
UpdateStatement
WhereClause