ScriptSqlTask class final

An SQL script consisting of multiple statements.

Inheritance

Constructors

ScriptSqlTask(List<String> statements)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script String
statements separated by ;\n.
no setter
statements List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited