BoolExt<T extends bool?> extension
Extension methods for wrapping a bool as an expression.
Properties
-
asExpr
→ Expr<T>
-
Available on T,
provided by the BoolExt extension
Wrap bool as an Expr expression for use with package:typed_sql.
no setter
-
asExprLiteral
→ Expr<T>
-
Available on T,
provided by the BoolExt extension
Wrap bool as an Expr literal for use with package:typed_sql.
no setter