CurrentTimestampExpression class final

Inheritance
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(Expr<DateTime?> other) Expr<bool?>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using = in SQL.
equalsValue(DateTime? other) Expr<bool?>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using = in SQL.
isAfter(Expr<DateTime> value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is after value.
isAfterValue(DateTime value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is after value.
isBefore(Expr<DateTime> value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is before value.
isBeforeValue(DateTime value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is before value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using <> in SQL.
notEqualsValue(DateTime other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using <> in SQL.
toString() String
A string representation of this object.
inherited

Operators

operator <(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator <=(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator ==(Object other) bool
The equality operator.
inherited
operator >(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator >=(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.