asEncoded method
Get an expression containing the encoded value of the CustomDataType implementation.
Implementation
Expr<S> asEncoded() =>
EncodedCustomDataTypeExpression<S, CustomDataType<S>>._(this).asNotNull();
Get an expression containing the encoded value of the CustomDataType implementation.
Expr<S> asEncoded() =>
EncodedCustomDataTypeExpression<S, CustomDataType<S>>._(this).asNotNull();