close abstract method
Close the database connection pool.
If called without force this must wait for all ongoing calls to
script, query, execute or transact to finish.
Once this has been called further calls to script, query, execute or transact shall throw StateError. Unless, these calls are taking place inside a transaction started before close was called.
If called with force set to true, all ongoing calls to script,
query, execute or transact shall throw a
DatabaseConnectionException.
Implementation
Future<void> close({bool force = false});