Expr<T extends Object?> class sealed Inserting rows Writing queries Update and delete

A representation of an SQL expression with type T.

Implementers
Available extensions

Constructors

Expr(T value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string is empty.
no setter
isNotEmpty Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string is not empty.
no setter
length Expr<int>

Available on Expr<String>, provided by the ExpressionString extension

Get the length of the string.
no setter
length Expr<int>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns the number of bytes in this BLOB.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
add(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
addValue(int other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
addValue(double other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
and(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical AND.
asBlob() Expr<Uint8List?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<Uint8List?> using CAST(NULL AS BLOB).
asBool() Expr<bool?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a boolean.
asBool() Expr<bool?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<bool?> using CAST(NULL AS BOOLEAN).
asDateTime() Expr<DateTime?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<DateTime?> using CAST(NULL AS TIMESTAMP).
asDouble() Expr<double>

Available on Expr<int>, provided by the ExpressionInt extension

Cast as double.
asDouble() Expr<double?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<double?> using CAST(NULL AS DOUBLE PRECISION).
asDouble() Expr<double?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a double.
asDouble() Expr<double>

Available on Expr<String>, provided by the ExpressionString extension

Cast as double.
asEncoded() Expr<S>

Available on Expr<CustomDataType<S>>, provided by the CustomTypeExt extension

Get an expression containing the encoded value of the CustomDataType implementation.
asEncoded() Expr<S?>

Available on Expr<CustomDataType<S>?>, provided by the CustomTypeNullableExt extension

Get an expression containing the encoded value of the CustomDataType implementation.
asInt() Expr<int?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to an integer.
asInt() Expr<int>

Available on Expr<double>, provided by the ExpressionDouble extension

Cast as integer.
asInt() Expr<int>

Available on Expr<bool>, provided by the ExpressionBool extension

Cast as integer.
asInt() Expr<int>

Available on Expr<String>, provided by the ExpressionString extension

Cast as integer.
asInt() Expr<int?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<int?> using CAST(NULL AS BIGINT).
asJsonValue() Expr<JsonValue?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<JsonValue?> using CAST(NULL AS JSONB).
asNotNull() Expr<T>

Available on Expr<T?>, provided by the ExpressionNullable extension

Cast as Expr<T> without doing anything in SQL.
asString() Expr<String>

Available on Expr<double>, provided by the ExpressionDouble extension

Cast as string.
asString() Expr<String>

Available on Expr<int>, provided by the ExpressionInt extension

Cast as string.
asString() Expr<String?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<String?> using CAST(NULL AS TEXT).
asString() Expr<String?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text.
concat(Expr<Uint8List> other) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Concatenates this BLOB with other.
contains(Expr<String> substring) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string contains substring.
containsValue(String substring) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string contains substring.
decodeUtf8() Expr<String>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Decodes the BLOB bytes as a UTF-8 string.
divide(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
divide(Expr<int> other) Expr<double>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
divideValue(double other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
divideValue(int other) Expr<double>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
elementAt(int index) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access an index in this JSON value.
endsWith(Expr<String> value) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string ends with value.
endsWithValue(String value) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string ends with value.
equals(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<T> other) Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<String> other) Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<bool> other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<Uint8List> other) Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<T?> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<String?> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<Uint8List?> other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<DateTime?> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using = in SQL coalesced to FALSE.
equals(Expr<bool?> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsUnlessNull(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using =.
equalsUnlessNull(Expr<T?> other) Expr<bool?>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using =.
equalsUnlessNull(Expr<String?> other) Expr<bool?>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using =.
equalsUnlessNull(Expr<Uint8List?> other) Expr<bool?>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using =.
equalsUnlessNull(Expr<DateTime?> other) Expr<bool?>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using =.
equalsValue(bool other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(String? other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(T other) Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(DateTime other) Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(T? other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(Uint8List? other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(DateTime? other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(bool? other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(String other) Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using = in SQL coalesced to FALSE.
equalsValue(Uint8List other) Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using = in SQL coalesced to FALSE.
field(String key) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key in this JSON value.
greaterThan(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
greaterThan(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
greaterThanOrEqual(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
greaterThanOrEqual(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
greaterThanOrEqualValue(String other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
greaterThanOrEqualValue(T other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
greaterThanValue(String other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
greaterThanValue(T other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
isAfter(Expr<DateTime> value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is after value.
isAfterValue(DateTime value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is after value.
isBefore(Expr<DateTime> value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is before value.
isBeforeValue(DateTime value) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is before value.
isFalse() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

True, if this expression evaluates to FALSE.
isNotDistinctFrom(Expr<bool?> other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotDistinctFrom(Expr<DateTime?> other) Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotDistinctFrom(Expr<T?> other) Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotDistinctFrom(Expr<String?> other) Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotDistinctFrom(Expr<Uint8List?> other) Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is not NULL.
isNotNull() Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Check if this expression is not NULL.
isNotNull() Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Check if this expression is not NULL.
isNotNull() Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Check if this expression is not NULL.
isNotNull() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Check if this expression is not NULL.
isNotNull() Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Check if this expression is not NULL.
isNull() Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Check if this expression is NULL.
isNull() Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Check if this expression is NULL.
isNull() Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Check if this expression is NULL.
isNull() Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Check if this expression is NULL.
isNull() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Check if this expression is NULL.
isNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is NULL.
isTrue() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

True, if this expression evaluates to TRUE.
lessThan(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
lessThan(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
lessThanOrEqual(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
lessThanOrEqual(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
lessThanOrEqualValue(String other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
lessThanOrEqualValue(T other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
lessThanValue(String other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
lessThanValue(T other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
like(String pattern) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Matches pattern where % is one or more characters, and _ is one character.
multiply(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
multiply(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
multiplyValue(double other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
multiplyValue(int other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Negate this expression.
notEquals(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using <> in SQL.
notEquals(Expr<bool?> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using <> in SQL.
notEquals(Expr<String?> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Compare this expression to other using <> in SQL.
notEquals(Expr<String> other) Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using <> in SQL.
notEquals(Expr<bool> other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using <> in SQL.
notEquals(Expr<Uint8List?> other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using <> in SQL.
notEquals(Expr<Uint8List> other) Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using <> in SQL.
notEquals(Expr<DateTime?> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using <> in SQL.
notEquals(Expr<T> other) Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using <> in SQL.
notEquals(Expr<T?> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Compare this expression to other using <> in SQL.
notEqualsValue(Uint8List other) Expr<bool>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

Compare this expression to other using <> in SQL.
notEqualsValue(String other) Expr<bool>

Available on Expr<String?>, provided by the ExpressionNullableString extension

Compare this expression to other using <> in SQL.
notEqualsValue(bool? other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using <> in SQL.
notEqualsValue(String? other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Compare this expression to other using <> in SQL.
notEqualsValue(T other) Expr<bool>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

Compare this expression to other using <> in SQL.
notEqualsValue(bool other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using <> in SQL.
notEqualsValue(DateTime other) Expr<bool>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

Compare this expression to other using <> in SQL.
notEqualsValue(Uint8List? other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using <> in SQL.
notEqualsValue(DateTime? other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Compare this expression to other using <> in SQL.
notEqualsValue(T? other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Compare this expression to other using <> in SQL.
or(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical OR.
orElse(Expr<Uint8List> value) Expr<Uint8List>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

If this expression is NULL, use value instead.
orElse(Expr<String> value) Expr<String>

Available on Expr<String?>, provided by the ExpressionNullableString extension

If this expression is NULL, use value instead.
orElse(Expr<bool> value) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

If this expression is NULL, use value instead.
orElse(Expr<T> value) Expr<T>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

If this expression is NULL, use value instead.
orElse(Expr<JsonValue> value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.
orElse(Expr<DateTime> value) Expr<DateTime>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

If this expression is NULL, use value instead.
orElseValue(String value) Expr<String>

Available on Expr<String?>, provided by the ExpressionNullableString extension

If this expression is NULL, use value instead.
orElseValue(bool value) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

If this expression is NULL, use value instead.
orElseValue(T value) Expr<T>

Available on Expr<T?>, provided by the ExpressionNullableNum extension

If this expression is NULL, use value instead.
orElseValue(Uint8List value) Expr<Uint8List>

Available on Expr<Uint8List?>, provided by the ExpressionNullableUint8List extension

If this expression is NULL, use value instead.
orElseValue(JsonValue value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.
orElseValue(DateTime value) Expr<DateTime>

Available on Expr<DateTime?>, provided by the ExpressionNullableDateTime extension

If this expression is NULL, use value instead.
startsWith(Expr<String> value) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string starts with value.
startsWithValue(String value) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if the string starts with value.
subList(Expr<int> start, {Expr<int>? length}) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns a new BLOB containing the bytes from start (0-based) for length.
subtract(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
subtract(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
subtractValue(double other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
subtractValue(int other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
toHex() Expr<String>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns the hexadecimal representation of this BLOB in UPPERCASE.
toLowerCase() Expr<String>

Available on Expr<String>, provided by the ExpressionString extension

Converts the string to lower case.
toString() String
A string representation of this object.
inherited
toUpperCase() Expr<String>

Available on Expr<String>, provided by the ExpressionString extension

Converts the string to upper case.

Operators

operator &(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical AND.
operator *(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
operator *(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
operator +(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
operator +(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
operator +(Expr<Uint8List> other) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Concatenates this BLOB with other.
operator -(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
operator -(Expr<int> other) Expr<int>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
operator /(Expr<double> other) Expr<double>

Available on Expr<double>, provided by the ExpressionDouble extension

Add this expression to other.
operator /(Expr<int> other) Expr<double>

Available on Expr<int>, provided by the ExpressionInt extension

Add this expression to other.
operator <(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator <(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
operator <(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
operator <=(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator <=(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
operator <=(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
operator ==(Object other) bool
The equality operator.
inherited
operator >(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator >(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
operator >(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
operator >=(Expr<DateTime> other) Expr<bool>

Available on Expr<DateTime>, provided by the ExpressionDateTime extension

Check if this expression is less than other.
operator >=(Expr<T> other) Expr<bool>

Available on Expr<T>, provided by the ExpressionNum extension

Check if this expression is less than other.
operator >=(Expr<String> other) Expr<bool>

Available on Expr<String>, provided by the ExpressionString extension

Check if this expression is less than other.
operator [](Object keyOrIndex) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key or index in this JSON value.
operator |(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical OR.
operator ~() Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Negate this expression.

Constants

currentTimestamp → const Expr<DateTime>
Get an Expr<DateTime> that represents the current timestamp in UTC.
false$ → const Expr<bool>
null$ → const Expr<Null>
true$ → const Expr<bool>