ExprValuesSource class final
Source of values for an InsertStatement that inserts a single row from Expr objects.
- Inheritance
-
- Object
- ValuesSource
- ExprValuesSource
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited