ExpressionBlobConcat class final

Inheritance
Available extensions

Constructors

ExpressionBlobConcat(Expr<Uint8List> left, Expr<Uint8List> right)

Properties

hashCode int
The hash code for this object.
no setterinherited
left Expr<Uint8List>
finalinherited
length Expr<int>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns the number of bytes in this BLOB.
no setter
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

concat(Expr<Uint8List> other) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Concatenates this BLOB with other.
decodeUtf8() Expr<String>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Decodes the BLOB bytes as a UTF-8 string.
equals(Expr<Uint8List?> other) Expr<bool?>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using = in SQL.
equalsValue(Uint8List? other) Expr<bool?>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using = in SQL.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(Expr<Uint8List> other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using <> in SQL.
notEqualsValue(Uint8List other) Expr<bool>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Compare this expression to other using <> in SQL.
subList(Expr<int> start, {Expr<int>? length}) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns a new BLOB containing the bytes from start (0-based) for length.
toHex() Expr<String>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Returns the hexadecimal representation of this BLOB in UPPERCASE.
toString() String
A string representation of this object.
inherited

Operators

operator +(Expr<Uint8List> other) Expr<Uint8List>

Available on Expr<Uint8List>, provided by the ExpressionUint8List extension

Concatenates this BLOB with other.
operator ==(Object other) bool
The equality operator.
inherited