notEquals method

Expr<bool> notEquals(
  1. Expr<bool> other
)

Compare this expression to other using <> in SQL.

This is equivalent to this <> other in SQL,

The .notEquals method avoids the surprising behavior where anything <> NULL evaluates to NULL by not allowing any operand to be nullable.

If you wish to compare nullable expressions you can use:

Implementation

Expr<bool> notEquals(Expr<bool> other) =>
    ExpressionNotEquals(this, other).asNotNull();