ExpressionJsonRef class sealed

Base class for JSON expressions reference a property or index in a JsonValue.

Inheritance
Implementers
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asBlob() Expr<Uint8List?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<Uint8List?> using CAST(NULL AS BLOB).
asBool() Expr<bool?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<bool?> using CAST(NULL AS BOOLEAN).
asBool() Expr<bool?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a boolean.
asDateTime() Expr<DateTime?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<DateTime?> using CAST(NULL AS TIMESTAMP).
asDouble() Expr<double?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<double?> using CAST(NULL AS DOUBLE PRECISION).
asDouble() Expr<double?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a double.
asInt() Expr<int?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<int?> using CAST(NULL AS BIGINT).
asInt() Expr<int?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to an integer.
asJsonValue() Expr<JsonValue?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<JsonValue?> using CAST(NULL AS JSONB).
asString() Expr<String?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<String?> using CAST(NULL AS TEXT).
asString() Expr<String?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text.
elementAt(int index) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access an index in this JSON value.
field(String key) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key in this JSON value.
isNotNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is not NULL.
isNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is NULL.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orElse(Expr<JsonValue> value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.
orElseValue(JsonValue value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object keyOrIndex) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key or index in this JSON value.