ExpressionNotEquals<T extends Object> class final

SQL Expression using <>.

Inheritance
Available extensions

Constructors

ExpressionNotEquals(Expr<T?> left, Expr<T?> right)

Properties

hashCode int
The hash code for this object.
no setterinherited
left Expr<T?>
finalinherited
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and<R extends bool?>(Expr<R> other) Expr<R>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical AND.
and(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Logical AND.
asBlob() Expr<Uint8List?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<Uint8List?> using CAST(NULL AS BLOB).
asBool() Expr<bool?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<bool?> using CAST(NULL AS BOOLEAN).
asDateTime() Expr<DateTime?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<DateTime?> using CAST(NULL AS TIMESTAMP).
asDouble() Expr<double?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<double?> using CAST(NULL AS DOUBLE PRECISION).
asInt() Expr<int>

Available on Expr<bool>, provided by the ExpressionBool extension

Cast as integer.
asInt() Expr<int?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<int?> using CAST(NULL AS BIGINT).
asJsonValue() Expr<JsonValue?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<JsonValue?> using CAST(NULL AS JSONB).
asString() Expr<String?>

Available on Expr<Null>, provided by the ExpressionNull extension

Cast as Expr<String?> using CAST(NULL AS TEXT).
equals(Expr<bool?> other) Expr<bool?>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using = in SQL.
equals(Expr<bool> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using = in SQL.
equalsUnlessNull(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using =.
equalsValue(bool? other) Expr<bool?>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using = in SQL.
equalsValue(bool other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using = in SQL.
isFalse() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

True, if this expression evaluates to FALSE.
isNotDistinctFrom(Expr<bool?> other) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Compare this expression to other using IS NOT DISTINCT FROM.
isNotNull() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Check if this expression is not NULL.
isNull() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Check if this expression is NULL.
isTrue() Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

True, if this expression evaluates to TRUE.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Negate this expression.
notEquals(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using <> in SQL.
notEqualsValue(bool other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Compare this expression to other using <> in SQL.
or<R extends bool?>(Expr<R> other) Expr<R>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical OR.
or(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Logical OR.
orElse(Expr<bool> value) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

If this expression is NULL, use value instead.
orElseValue(bool value) Expr<bool>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

If this expression is NULL, use value instead.
toString() String
A string representation of this object.
inherited

Operators

operator &(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical AND.
operator &(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Logical AND.
operator ==(Object other) bool
The equality operator.
inherited
operator |(Expr<bool> other) Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Logical OR.
operator |(Expr<bool?> other) Expr<bool?>

Available on Expr<bool?>, provided by the ExpressionNullableBool extension

Logical OR.
operator ~() Expr<bool>

Available on Expr<bool>, provided by the ExpressionBool extension

Negate this expression.