asDouble method

Expr<double?> asDouble()

Cast as Expr<double?> using CAST(NULL AS DOUBLE PRECISION).

This method is rarely necessary, as you can generally pass toExpr(null) to any method expecting an Expr<double?>. But in some complex scenarios this can alleviate type inference issues.

Implementation

Expr<double?> asDouble() => CastExpression._(this, ColumnType.real);