ExpressionNullableJsonValue extension

Extension methods for nullable JsonValue expressions.

on

Methods

asBool() Expr<bool?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a boolean.
asDouble() Expr<double?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to a double.
asInt() Expr<int?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text and cast it to an integer.
asString() Expr<String?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Extract the value as unquoted text.
elementAt(int index) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access an index in this JSON value.
field(String key) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key in this JSON value.
isNotNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is not NULL.
isNull() Expr<bool>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Check if this expression is NULL.
orElse(Expr<JsonValue> value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.
orElseValue(JsonValue value) Expr<JsonValue>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

If this expression is NULL, use value instead.

Operators

operator [](Object keyOrIndex) Expr<JsonValue?>

Available on Expr<JsonValue?>, provided by the ExpressionNullableJsonValue extension

Access a key or index in this JSON value.