equals method

Expr<bool?> equals(
  1. Expr<String> other
)

Compare this expression to other using = in SQL.

This is equivalent to this = other in SQL, which if one of the operands is NULL will evaluate to NULL, following SQL three-valued logic.

The .equals method avoids the surprising behavior where NULL = NULL evaluates to NULL by not allowing comparison between two nullable operands.

If you wish to compare nullable expressions you can use:

Implementation

Expr<bool?> equals(Expr<String> other) => ExpressionEquals(this, other);