notEqualsValue method

Expr<bool> notEqualsValue(
  1. String other
)

Compare this expression to other using <> in SQL.

This is equivalent to this <> other in SQL,

The .notEquals method avoids the surprising behavior where anything <> NULL evaluates to NULL by not allowing any operand to be nullable.

If you wish to compare nullable expressions you can use:

  • isNotDistinctFrom, to get NULL equivalent to NULL, or,
  • equalsUnlessNull, to explicitely get the SQL = semantics.

Implementation

Expr<bool> notEqualsValue(String other) => notEquals(toExpr(other));