InsertOnConflictSingle<T extends Row> class final

An INSERT ... ON CONFLICT ... statement builder.

Holding an InsertOnConflictSingle builder, you may:

  • Use .doNothing() to build an INSERT statement that ignores the row if it triggers a conflict on the previously specified conflict target.
  • Use .update((row, excluded, set) => set(...)) to specify an mutation on the conflicting row in the database.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

doNothing() InsertOrIgnoreSingle<T>
Create an INSERT statement that skips the row to be inserted, if it conflicts with existing an existing row on the conflict target.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited