Query<T extends Record> class
final
Writing queries
A Query on the database from which results can be fetched.
- Implementers
- Available extensions
Properties
-
asSubQuery
→ SubQuery<
T> -
Available on Query<
Use this Query as a SubQuery.T> , provided by the QueryExt extensionno setter -
first
→ QuerySingle<
(Expr< A> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query1 extensionA> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query2 extensionA> , Expr<B> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>LIMITclause.no setter -
first
→ QuerySingle<
(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Limit Query to the first row using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>LIMITclause.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
avg(
) → QuerySingle< (Expr< double?> )> -
Available on Query<
Take the average of the rows in this query using the(Expr< , provided by the QueryReal extensiondouble?> )>AVGaggregate function. -
avg(
) → QuerySingle< (Expr< double?> )> -
Available on Query<
Take the average of the rows in this query using the(Expr< , provided by the QueryInteger extensionint?> )>AVGaggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query1 extensionA> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>COUNT(*)aggregate function. -
count(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Count number of rows in this Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>COUNT(*)aggregate function. -
distinct(
) → Query< T> -
Available on Query<
Create a query with distinct rows from this query using theT> , provided by the QueryExt extensionDISTINCTkeyword. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingEXCEPTset operator. -
except(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingEXCEPTset operator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query1 extensionA> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>EXISTSoperator. -
exists(
) → QuerySingle< (Expr< bool> )> -
Available on Query<
Check for existance of rows in this Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>EXISTSoperator. -
fetch(
) → Future< List< (A, B, C, D)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )> -
fetch(
) → Future< List< A> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query1 extensionA> )> -
fetch(
) → Future< List< (A, B)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query2 extensionA> , Expr<B> )> -
fetch(
) → Future< List< (A, B, C, D, E, F, G)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
fetch(
) → Future< List< (A, B, C, D, E)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
fetch(
) → Future< List< (A, B, C)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )> -
fetch(
) → Future< List< (A, B, C, D, E, F, G, H)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
fetch(
) → Future< List< (A, B, C, D, E, F)> > -
Available on Query<
Query the database for rows in this Query as a List.(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b)) → Group<T, (Expr< A> , Expr<B> )> -
Available on Query<
Create projection for(Expr< , provided by the Query2 extensionA> , Expr<B> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f)) → Group<T, (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Create projection for(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e)) → Group<T, (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Create projection for(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a)) → Group<T, (Expr< A> )> -
Available on Query<
Create projection for(Expr< , provided by the Query1 extensionA> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g, Expr<H> h)) → Group<T, (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Create projection for(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d)) → Group<T, (Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Create projection for(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g)) → Group<T, (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Create projection for(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>GROUP BYclause. -
groupBy<
T extends Record> (T groupBuilder(Expr< A> a, Expr<B> b, Expr<C> c)) → Group<T, (Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Create projection for(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>GROUP BYclause. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingINTERSECTset operator. -
intersect(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingINTERSECTset operator. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query1 extensionA> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>INNER JOINclause. -
join<
T extends Record> (Query< T> query) → InnerJoin<(Expr< A> , Expr<B> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>INNER JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>LEFT JOINclause. -
leftJoin<
T extends Record> (Query< T> query) → LeftJoin<(Expr< A> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query1 extensionA> )>LEFT JOINclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>LIMITclause. -
limit(
int limit) → Query< (Expr< A> )> -
Available on Query<
Limit Query using(Expr< , provided by the Query1 extensionA> )>LIMITclause. -
max(
) → QuerySingle< (Expr< DateTime?> )> -
Available on Query<
Take the largest row of the rows in this query using the(Expr< , provided by the QueryDateTime extensionDateTime?> )>MAXaggregate function. -
max(
) → QuerySingle< (Expr< double?> )> -
Available on Query<
Take the largest row of the rows in this query using the(Expr< , provided by the QueryReal extensiondouble?> )>MAXaggregate function. -
max(
) → QuerySingle< (Expr< String?> )> -
Available on Query<
Take the largest row of the rows in this query using the(Expr< , provided by the QueryString extensionString?> )>MAXaggregate function. -
max(
) → QuerySingle< (Expr< int?> )> -
Available on Query<
Take the largest row of the rows in this query using the(Expr< , provided by the QueryInteger extensionint?> )>MAXaggregate function. -
min(
) → QuerySingle< (Expr< String?> )> -
Available on Query<
Take the smallest row of the rows in this query using the(Expr< , provided by the QueryString extensionString?> )>MINaggregate function. -
min(
) → QuerySingle< (Expr< double?> )> -
Available on Query<
Take the smallest row of the rows in this query using the(Expr< , provided by the QueryReal extensiondouble?> )>MINaggregate function. -
min(
) → QuerySingle< (Expr< int?> )> -
Available on Query<
Take the smallest row of the rows in this query using the(Expr< , provided by the QueryInteger extensionint?> )>MINaggregate function. -
min(
) → QuerySingle< (Expr< DateTime?> )> -
Available on Query<
Take the smallest row of the rows in this query using the(Expr< , provided by the QueryDateTime extensionDateTime?> )>MINaggregate function. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offset(
int offset) → Query< (Expr< A> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query1 extensionA> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>OFFSETclause. -
offset(
int offset) → Query< (Expr< A> , Expr<B> )> -
Available on Query<
Offset Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>OFFSETclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g, Expr<H> h)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Order Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Order Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Order Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Order Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Order Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b, Expr<C> c, Expr<D> d)) → OrderedQuery<(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Order Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a)) → OrderedQuery<(Expr< A> )> -
Available on Query<
Order Query using(Expr< , provided by the Query1 extensionA> )>ORDER BYclause. -
orderBy(
List< (Expr< builder(Expr<Comparable?> , Order)>A> a, Expr<B> b)) → OrderedQuery<(Expr< A> , Expr<B> )> -
Available on Query<
Order Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>ORDER BYclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query1 extensionA> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>RIGHT JOINclause. -
rightJoin<
T extends Record> (Query< T> query) → RightJoin<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> ), T> -
Available on Query<
Join this Query with another Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>RIGHT JOINclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query1 extensionA> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g, Expr<H> h)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>SELECTclause. -
select<
T extends Record> (T projectionBuilder(Expr< A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f)) → Query<T> -
Available on Query<
Create a projection of this Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>SELECTclause. -
stream(
) → Stream< (A, B)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query2 extensionA> , Expr<B> )> -
stream(
) → Stream< (A, B, C, D, E, F, G, H)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
stream(
) → Stream< (A, B, C, D, E, F)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
stream(
) → Stream< (A, B, C, D, E)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
stream(
) → Stream< (A, B, C, D)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )> -
stream(
) → Stream< (A, B, C)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )> -
stream(
) → Stream< A> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query1 extensionA> )> -
stream(
) → Stream< (A, B, C, D, E, F, G)> -
Available on Query<
Query the database for rows in this Query as a Stream.(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
sum(
) → QuerySingle< (Expr< double> )> -
Available on Query<
Take the sum of the rows in this query using the(Expr< , provided by the QueryReal extensiondouble?> )>SUMaggregate function. -
sum(
) → QuerySingle< (Expr< int> )> -
Available on Query<
Take the sum of the rows in this query using the(Expr< , provided by the QueryInteger extensionint?> )>SUMaggregate function. -
toString(
) → String -
A string representation of this object.
inherited
-
union(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingUNIONset operator. -
union(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingUNIONset operator. -
unionAll(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingUNION ALLset operator. -
unionAll(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingUNION ALLset operator. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g)) → Query<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f, Expr<G> g, Expr<H> h)) → Query<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b)) → Query<(Expr< A> , Expr<B> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query2 extensionA> , Expr<B> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c)) → Query<(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e, Expr<F> f)) → Query<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c, Expr<D> d, Expr<E> e)) → Query<(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a, Expr<B> b, Expr<C> c, Expr<D> d)) → Query<(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>WHEREclause. -
where(
Expr< bool?> conditionBuilder(Expr<A> a)) → Query<(Expr< A> )> -
Available on Query<
Filter Query using(Expr< , provided by the Query1 extensionA> )>WHEREclause.
Operators
-
operator &(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingINTERSECTset operator. -
operator &(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingINTERSECTset operator. -
operator +(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingUNION ALLset operator. -
operator +(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingUNION ALLset operator. -
operator -(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingUNIONset operator. -
operator -(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingUNIONset operator. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
Query< (Expr< other) → Query<A> )>(Expr< A> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query1 extensionA> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> )>(Expr< A> , Expr<B> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query2 extensionA> , Expr<B> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> )>(Expr< A> , Expr<B> , Expr<C> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query3 extensionA> , Expr<B> , Expr<C> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query4 extensionA> , Expr<B> , Expr<C> , Expr<D> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query5 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query6 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query7 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> )>otherusingEXCEPTset operator. -
operator |(
Query< (Expr< other) → Query<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>(Expr< A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )> -
Available on Query<
Combine this Query with(Expr< , provided by the Query8 extensionA> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> , Expr<G> , Expr<H> )>otherusingEXCEPTset operator.