leftJoin<T extends Record> method

LeftJoin<(Expr<A>, Expr<B>, Expr<C>), T> leftJoin<T extends Record>(
  1. Query<T> query
)

Join this Query with another Query using LEFT JOIN clause.

This method returns an LeftJoin object on which you must call .on to specify how the two queries should be joined.

This always creates a LEFT JOIN, where the .on condition can be used to control how the two queries are joined.

Implementation

LeftJoin<(Expr<A>, Expr<B>, Expr<C>), T> leftJoin<T extends Record>(
  Query<T> query,
) => LeftJoin._(this, query);