union method

Query<(Expr<A>, Expr<B>, Expr<C>)> union(
  1. Query<(Expr<A>, Expr<B>, Expr<C>)> other
)

Combine this Query with other using UNION set operator.

This returns a Query containing all the rows from this Query and other with duplicate rows appearing only once.

Implementation

Query<(Expr<A>, Expr<B>, Expr<C>)> union(
  Query<(Expr<A>, Expr<B>, Expr<C>)> other,
) => Query._(
  _context,
  _expressions,
  (e) => UnionClause._(_from(_expressions.toList()), other._castAs(this)),
);