rightJoin<T extends Record> method

RightJoin<(Expr<A>, Expr<B>, Expr<C>, Expr<D>), T> rightJoin<T extends Record>(
  1. Query<T> query
)

Join this Query with another Query using RIGHT JOIN clause.

This method returns an RightJoin object on which you must call .on to specify how the two queries should be joined.

This always creates a RIGHT JOIN, where the .on condition can be used to control how the two queries are joined.

Implementation

RightJoin<(Expr<A>, Expr<B>, Expr<C>, Expr<D>), T>
rightJoin<T extends Record>(Query<T> query) => RightJoin._(this, query);