max method

QuerySingle<(Expr<int?>)> max()

Take the largest row of the rows in this query using the MAX aggregate function.

This is equivalent to SELECT MAX(column1) FROM this in SQL.

Note

Like the MAX aggregate function in SQL, this method will return NULL if there are no rows or if all rows are NULL.

Implementation

QuerySingle<(Expr<int?>,)> max() =>
    select((a) => (MaxExpression._(a),)).first;