min method

QuerySingle<(Expr<double?>)> min()

Take the smallest row of the rows in this query using the MIN aggregate function.

This is equivalent to SELECT MIN(column1) FROM this in SQL.

Note

Like the MIN aggregate function in SQL, this method will return NULL if there are no rows or if all rows are NULL.

Implementation

QuerySingle<(Expr<double?>,)> min() =>
    select((a) => (MinExpression._(a),)).first;