CurrentTimestampExpression class final
- Inheritance
-
- Object
- Expr<
DateTime> - SingleValueExpr<
DateTime> - CurrentTimestampExpression
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
equals(
Expr< DateTime?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing=in SQL. -
equalsValue(
DateTime? other) → Expr< bool?> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing=in SQL. -
isAfter(
Expr< DateTime> value) → Expr<bool> -
Available on Expr<
Check if this expression is afterDateTime> , provided by the ExpressionDateTime extensionvalue. -
isAfterValue(
DateTime value) → Expr< bool> -
Available on Expr<
Check if this expression is afterDateTime> , provided by the ExpressionDateTime extensionvalue. -
isBefore(
Expr< DateTime> value) → Expr<bool> -
Available on Expr<
Check if this expression is beforeDateTime> , provided by the ExpressionDateTime extensionvalue. -
isBeforeValue(
DateTime value) → Expr< bool> -
Available on Expr<
Check if this expression is beforeDateTime> , provided by the ExpressionDateTime extensionvalue. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing<>in SQL. -
notEqualsValue(
DateTime other) → Expr< bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing<>in SQL. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator <(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator <=(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator >=(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother.