Expr<T extends Object?> class
sealed
Inserting rows
Writing queries
Update and delete
A representation of an SQL expression with type T.
- Implementers
- Available extensions
- CustomTypeExt
- CustomTypeNullableExt
- ExpressionBool
- ExpressionDateTime
- ExpressionDouble
- ExpressionInt
- ExpressionJsonValue
- ExpressionNull
- ExpressionNullable
- ExpressionNullableBool
- ExpressionNullableDateTime
- ExpressionNullableJsonValue
- ExpressionNullableNum
- ExpressionNullableString
- ExpressionNullableUint8List
- ExpressionNum
- ExpressionString
- ExpressionUint8List
Constructors
- Expr(T value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isEmpty
→ Expr<
bool> -
Available on Expr<
Check if the string is empty.String> , provided by the ExpressionString extensionno setter -
isNotEmpty
→ Expr<
bool> -
Available on Expr<
Check if the string is not empty.String> , provided by the ExpressionString extensionno setter -
length
→ Expr<
int> -
Available on Expr<
Get the length of the string.String> , provided by the ExpressionString extensionno setter -
length
→ Expr<
int> -
Available on Expr<
Returns the number of bytes in this BLOB.Uint8List> , provided by the ExpressionUint8List extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
add(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
addValue(
int other) → Expr< int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
addValue(
double other) → Expr< double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
and(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Logical AND.bool> , provided by the ExpressionBool extension -
asBlob(
) → Expr< Uint8List?> -
Available on Expr<
Cast as Expr<Uint8List?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BLOB). -
asBool(
) → Expr< bool?> -
Available on Expr<
Extract the value as unquoted text and cast it to a boolean.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asBool(
) → Expr< bool?> -
Available on Expr<
Cast as Expr<bool?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BOOLEAN). -
asDateTime(
) → Expr< DateTime?> -
Available on Expr<
Cast as Expr<DateTime?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS TIMESTAMP). -
asDouble(
) → Expr< double> -
Available on Expr<
Cast as double.int> , provided by the ExpressionInt extension -
asDouble(
) → Expr< double?> -
Available on Expr<
Cast as Expr<double?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS DOUBLE PRECISION). -
asDouble(
) → Expr< double?> -
Available on Expr<
Extract the value as unquoted text and cast it to a double.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asDouble(
) → Expr< double> -
Available on Expr<
Cast as double.String> , provided by the ExpressionString extension -
asEncoded(
) → Expr< S> -
Available on Expr<
Get an expression containing the encoded value of the CustomDataType implementation.CustomDataType< , provided by the CustomTypeExt extensionS> > -
asEncoded(
) → Expr< S?> -
Available on Expr<
Get an expression containing the encoded value of the CustomDataType implementation.CustomDataType< , provided by the CustomTypeNullableExt extensionS> ?> -
asInt(
) → Expr< int?> -
Available on Expr<
Extract the value as unquoted text and cast it to an integer.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asInt(
) → Expr< int> -
Available on Expr<
Cast as integer.double> , provided by the ExpressionDouble extension -
asInt(
) → Expr< int> -
Available on Expr<
Cast as integer.bool> , provided by the ExpressionBool extension -
asInt(
) → Expr< int> -
Available on Expr<
Cast as integer.String> , provided by the ExpressionString extension -
asInt(
) → Expr< int?> -
Available on Expr<
Cast as Expr<int?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BIGINT). -
asJsonValue(
) → Expr< JsonValue?> -
Available on Expr<
Cast as Expr<JsonValue?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS JSONB). -
asNotNull(
) → Expr< T> -
Available on Expr<
Cast as Expr<T> without doing anything in SQL.T?> , provided by the ExpressionNullable extension -
asString(
) → Expr< String> -
Available on Expr<
Cast as string.double> , provided by the ExpressionDouble extension -
asString(
) → Expr< String> -
Available on Expr<
Cast as string.int> , provided by the ExpressionInt extension -
asString(
) → Expr< String?> -
Available on Expr<
Cast as Expr<String?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS TEXT). -
asString(
) → Expr< String?> -
Available on Expr<
Extract the value as unquoted text.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
concat(
Expr< Uint8List> other) → Expr<Uint8List> -
Available on Expr<
Concatenates this BLOB withUint8List> , provided by the ExpressionUint8List extensionother. -
contains(
Expr< String> substring) → Expr<bool> -
Available on Expr<
Check if the string containsString> , provided by the ExpressionString extensionsubstring. -
containsValue(
String substring) → Expr< bool> -
Available on Expr<
Check if the string containsString> , provided by the ExpressionString extensionsubstring. -
decodeUtf8(
) → Expr< String> -
Available on Expr<
Decodes the BLOB bytes as a UTF-8 string.Uint8List> , provided by the ExpressionUint8List extension -
divide(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
divide(
Expr< int> other) → Expr<double> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
divideValue(
double other) → Expr< double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
divideValue(
int other) → Expr< double> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
elementAt(
int index) → Expr< JsonValue?> -
Available on Expr<
Access an index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
endsWith(
Expr< String> value) → Expr<bool> -
Available on Expr<
Check if the string ends withString> , provided by the ExpressionString extensionvalue. -
endsWithValue(
String value) → Expr< bool> -
Available on Expr<
Check if the string ends withString> , provided by the ExpressionString extensionvalue. -
equals(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< T> other) → Expr<bool> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< String> other) → Expr<bool> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< Uint8List> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< T?> other) → Expr<bool> -
Available on Expr<
Compare this expression toT> , provided by the ExpressionNum extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< String?> other) → Expr<bool> -
Available on Expr<
Compare this expression toString> , provided by the ExpressionString extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< Uint8List?> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< DateTime?> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing=in SQL coalesced toFALSE. -
equals(
Expr< bool?> other) → Expr<bool> -
Available on Expr<
Compare this expression tobool> , provided by the ExpressionBool extensionotherusing=in SQL coalesced toFALSE. -
equalsUnlessNull(
Expr< bool?> other) → Expr<bool?> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusing=. -
equalsUnlessNull(
Expr< T?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusing=. -
equalsUnlessNull(
Expr< String?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusing=. -
equalsUnlessNull(
Expr< Uint8List?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusing=. -
equalsUnlessNull(
Expr< DateTime?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusing=. -
equalsValue(
bool other) → Expr< bool> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
String? other) → Expr< bool> -
Available on Expr<
Compare this expression toString> , provided by the ExpressionString extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
T other) → Expr< bool> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
DateTime other) → Expr< bool> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
T? other) → Expr< bool> -
Available on Expr<
Compare this expression toT> , provided by the ExpressionNum extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
Uint8List? other) → Expr< bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
DateTime? other) → Expr< bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
bool? other) → Expr< bool> -
Available on Expr<
Compare this expression tobool> , provided by the ExpressionBool extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
String other) → Expr< bool> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusing=in SQL coalesced toFALSE. -
equalsValue(
Uint8List other) → Expr< bool> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusing=in SQL coalesced toFALSE. -
field(
String key) → Expr< JsonValue?> -
Available on Expr<
Access a key in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
greaterThan(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
greaterThan(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
greaterThanOrEqual(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
greaterThanOrEqual(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
greaterThanOrEqualValue(
String other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
greaterThanOrEqualValue(
T other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
greaterThanValue(
String other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
greaterThanValue(
T other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
isAfter(
Expr< DateTime> value) → Expr<bool> -
Available on Expr<
Check if this expression is afterDateTime> , provided by the ExpressionDateTime extensionvalue. -
isAfterValue(
DateTime value) → Expr< bool> -
Available on Expr<
Check if this expression is afterDateTime> , provided by the ExpressionDateTime extensionvalue. -
isBefore(
Expr< DateTime> value) → Expr<bool> -
Available on Expr<
Check if this expression is beforeDateTime> , provided by the ExpressionDateTime extensionvalue. -
isBeforeValue(
DateTime value) → Expr< bool> -
Available on Expr<
Check if this expression is beforeDateTime> , provided by the ExpressionDateTime extensionvalue. -
isFalse(
) → Expr< bool> -
Available on Expr<
True, if this expression evaluates tobool?> , provided by the ExpressionNullableBool extensionFALSE. -
isNotDistinctFrom(
Expr< bool?> other) → Expr<bool> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusingIS NOT DISTINCT FROM. -
isNotDistinctFrom(
Expr< DateTime?> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusingIS NOT DISTINCT FROM. -
isNotDistinctFrom(
Expr< T?> other) → Expr<bool> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusingIS NOT DISTINCT FROM. -
isNotDistinctFrom(
Expr< String?> other) → Expr<bool> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusingIS NOT DISTINCT FROM. -
isNotDistinctFrom(
Expr< Uint8List?> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusingIS NOT DISTINCT FROM. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notUint8List?> , provided by the ExpressionNullableUint8List extensionNULL. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notT?> , provided by the ExpressionNullableNum extensionNULL. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notDateTime?> , provided by the ExpressionNullableDateTime extensionNULL. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notbool?> , provided by the ExpressionNullableBool extensionNULL. -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notString?> , provided by the ExpressionNullableString extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isDateTime?> , provided by the ExpressionNullableDateTime extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isT?> , provided by the ExpressionNullableNum extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isString?> , provided by the ExpressionNullableString extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isUint8List?> , provided by the ExpressionNullableUint8List extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isbool?> , provided by the ExpressionNullableBool extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
isTrue(
) → Expr< bool> -
Available on Expr<
True, if this expression evaluates tobool?> , provided by the ExpressionNullableBool extensionTRUE. -
lessThan(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
lessThan(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
lessThanOrEqual(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
lessThanOrEqual(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
lessThanOrEqualValue(
String other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
lessThanOrEqualValue(
T other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
lessThanValue(
String other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
lessThanValue(
T other) → Expr< bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
like(
String pattern) → Expr< bool> -
Available on Expr<
Matches pattern whereString> , provided by the ExpressionString extension%is one or more characters, and_is one character. -
multiply(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
multiply(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
multiplyValue(
double other) → Expr< double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
multiplyValue(
int other) → Expr< int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Expr< bool> -
Available on Expr<
Negate this expression.bool> , provided by the ExpressionBool extension -
notEquals(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusing<>in SQL. -
notEquals(
Expr< bool?> other) → Expr<bool> -
Available on Expr<
Compare this expression tobool> , provided by the ExpressionBool extensionotherusing<>in SQL. -
notEquals(
Expr< String?> other) → Expr<bool> -
Available on Expr<
Compare this expression toString> , provided by the ExpressionString extensionotherusing<>in SQL. -
notEquals(
Expr< String> other) → Expr<bool> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusing<>in SQL. -
notEquals(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusing<>in SQL. -
notEquals(
Expr< Uint8List?> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing<>in SQL. -
notEquals(
Expr< Uint8List> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusing<>in SQL. -
notEquals(
Expr< DateTime?> other) → Expr<bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing<>in SQL. -
notEquals(
Expr< T> other) → Expr<bool> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusing<>in SQL. -
notEquals(
Expr< T?> other) → Expr<bool> -
Available on Expr<
Compare this expression toT> , provided by the ExpressionNum extensionotherusing<>in SQL. -
notEqualsValue(
Uint8List other) → Expr< bool> -
Available on Expr<
Compare this expression toUint8List?> , provided by the ExpressionNullableUint8List extensionotherusing<>in SQL. -
notEqualsValue(
String other) → Expr< bool> -
Available on Expr<
Compare this expression toString?> , provided by the ExpressionNullableString extensionotherusing<>in SQL. -
notEqualsValue(
bool? other) → Expr< bool> -
Available on Expr<
Compare this expression tobool> , provided by the ExpressionBool extensionotherusing<>in SQL. -
notEqualsValue(
String? other) → Expr< bool> -
Available on Expr<
Compare this expression toString> , provided by the ExpressionString extensionotherusing<>in SQL. -
notEqualsValue(
T other) → Expr< bool> -
Available on Expr<
Compare this expression toT?> , provided by the ExpressionNullableNum extensionotherusing<>in SQL. -
notEqualsValue(
bool other) → Expr< bool> -
Available on Expr<
Compare this expression tobool?> , provided by the ExpressionNullableBool extensionotherusing<>in SQL. -
notEqualsValue(
DateTime other) → Expr< bool> -
Available on Expr<
Compare this expression toDateTime?> , provided by the ExpressionNullableDateTime extensionotherusing<>in SQL. -
notEqualsValue(
Uint8List? other) → Expr< bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing<>in SQL. -
notEqualsValue(
DateTime? other) → Expr< bool> -
Available on Expr<
Compare this expression toDateTime> , provided by the ExpressionDateTime extensionotherusing<>in SQL. -
notEqualsValue(
T? other) → Expr< bool> -
Available on Expr<
Compare this expression toT> , provided by the ExpressionNum extensionotherusing<>in SQL. -
or(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Logical OR.bool> , provided by the ExpressionBool extension -
orElse(
Expr< Uint8List> value) → Expr<Uint8List> -
Available on Expr<
If this expression isUint8List?> , provided by the ExpressionNullableUint8List extensionNULL, usevalueinstead. -
orElse(
Expr< String> value) → Expr<String> -
Available on Expr<
If this expression isString?> , provided by the ExpressionNullableString extensionNULL, usevalueinstead. -
orElse(
Expr< bool> value) → Expr<bool> -
Available on Expr<
If this expression isbool?> , provided by the ExpressionNullableBool extensionNULL, usevalueinstead. -
orElse(
Expr< T> value) → Expr<T> -
Available on Expr<
If this expression isT?> , provided by the ExpressionNullableNum extensionNULL, usevalueinstead. -
orElse(
Expr< JsonValue> value) → Expr<JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead. -
orElse(
Expr< DateTime> value) → Expr<DateTime> -
Available on Expr<
If this expression isDateTime?> , provided by the ExpressionNullableDateTime extensionNULL, usevalueinstead. -
orElseValue(
String value) → Expr< String> -
Available on Expr<
If this expression isString?> , provided by the ExpressionNullableString extensionNULL, usevalueinstead. -
orElseValue(
bool value) → Expr< bool> -
Available on Expr<
If this expression isbool?> , provided by the ExpressionNullableBool extensionNULL, usevalueinstead. -
orElseValue(
T value) → Expr< T> -
Available on Expr<
If this expression isT?> , provided by the ExpressionNullableNum extensionNULL, usevalueinstead. -
orElseValue(
Uint8List value) → Expr< Uint8List> -
Available on Expr<
If this expression isUint8List?> , provided by the ExpressionNullableUint8List extensionNULL, usevalueinstead. -
orElseValue(
JsonValue value) → Expr< JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead. -
orElseValue(
DateTime value) → Expr< DateTime> -
Available on Expr<
If this expression isDateTime?> , provided by the ExpressionNullableDateTime extensionNULL, usevalueinstead. -
startsWith(
Expr< String> value) → Expr<bool> -
Available on Expr<
Check if the string starts withString> , provided by the ExpressionString extensionvalue. -
startsWithValue(
String value) → Expr< bool> -
Available on Expr<
Check if the string starts withString> , provided by the ExpressionString extensionvalue. -
subList(
Expr< int> start, {Expr<int> ? length}) → Expr<Uint8List> -
Available on Expr<
Returns a new BLOB containing the bytes fromUint8List> , provided by the ExpressionUint8List extensionstart(0-based) forlength. -
subtract(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
subtract(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
subtractValue(
double other) → Expr< double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
subtractValue(
int other) → Expr< int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
toHex(
) → Expr< String> -
Available on Expr<
Returns the hexadecimal representation of this BLOB in UPPERCASE.Uint8List> , provided by the ExpressionUint8List extension -
toLowerCase(
) → Expr< String> -
Available on Expr<
Converts the string to lower case.String> , provided by the ExpressionString extension -
toString(
) → String -
A string representation of this object.
inherited
-
toUpperCase(
) → Expr< String> -
Available on Expr<
Converts the string to upper case.String> , provided by the ExpressionString extension
Operators
-
operator &(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Logical AND.bool> , provided by the ExpressionBool extension -
operator *(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
operator *(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
operator +(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
operator +(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
operator +(
Expr< Uint8List> other) → Expr<Uint8List> -
Available on Expr<
Concatenates this BLOB withUint8List> , provided by the ExpressionUint8List extensionother. -
operator -(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
operator -(
Expr< int> other) → Expr<int> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
operator /(
Expr< double> other) → Expr<double> -
Available on Expr<
Add this expression todouble> , provided by the ExpressionDouble extensionother. -
operator /(
Expr< int> other) → Expr<double> -
Available on Expr<
Add this expression toint> , provided by the ExpressionInt extensionother. -
operator <(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator <(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
operator <(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
operator <=(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator <=(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
operator <=(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator >(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
operator >(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
operator >=(
Expr< DateTime> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanDateTime> , provided by the ExpressionDateTime extensionother. -
operator >=(
Expr< T> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanT> , provided by the ExpressionNum extensionother. -
operator >=(
Expr< String> other) → Expr<bool> -
Available on Expr<
Check if this expression is less thanString> , provided by the ExpressionString extensionother. -
operator [](
Object keyOrIndex) → Expr< JsonValue?> -
Available on Expr<
Access a key or index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
operator |(
Expr< bool> other) → Expr<bool> -
Available on Expr<
Logical OR.bool> , provided by the ExpressionBool extension -
operator ~(
) → Expr< bool> -
Available on Expr<
Negate this expression.bool> , provided by the ExpressionBool extension