ExpressionBlobConcat class final
- Inheritance
-
- Object
- Expr<
Uint8List> - SingleValueExpr<
Uint8List> - BinaryOperationExpression<
Uint8List, Uint8List> - ExpressionBlobConcat
- Available extensions
Constructors
-
ExpressionBlobConcat(Expr<
Uint8List> left, Expr<Uint8List> right)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
left
→ Expr<
Uint8List> -
finalinherited
-
length
→ Expr<
int> -
Available on Expr<
Returns the number of bytes in this BLOB.Uint8List> , provided by the ExpressionUint8List extensionno setter -
right
→ Expr<
Uint8List> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
concat(
Expr< Uint8List> other) → Expr<Uint8List> -
Available on Expr<
Concatenates this BLOB withUint8List> , provided by the ExpressionUint8List extensionother. -
decodeUtf8(
) → Expr< String> -
Available on Expr<
Decodes the BLOB bytes as a UTF-8 string.Uint8List> , provided by the ExpressionUint8List extension -
equals(
Expr< Uint8List?> other) → Expr<bool?> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing=in SQL. -
equalsValue(
Uint8List? other) → Expr< bool?> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing=in SQL. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
Expr< Uint8List> other) → Expr<bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing<>in SQL. -
notEqualsValue(
Uint8List other) → Expr< bool> -
Available on Expr<
Compare this expression toUint8List> , provided by the ExpressionUint8List extensionotherusing<>in SQL. -
subList(
Expr< int> start, {Expr<int> ? length}) → Expr<Uint8List> -
Available on Expr<
Returns a new BLOB containing the bytes fromUint8List> , provided by the ExpressionUint8List extensionstart(0-based) forlength. -
toHex(
) → Expr< String> -
Available on Expr<
Returns the hexadecimal representation of this BLOB in UPPERCASE.Uint8List> , provided by the ExpressionUint8List extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator +(
Expr< Uint8List> other) → Expr<Uint8List> -
Available on Expr<
Concatenates this BLOB withUint8List> , provided by the ExpressionUint8List extensionother. -
operator ==(
Object other) → bool -
The equality operator.
inherited