ExpressionJsonRef class sealed
Base class for JSON expressions reference a property or index in a JsonValue.
- Inheritance
-
- Object
- Expr<
JsonValue?> - SingleValueExpr<
JsonValue?> - ExpressionJsonRef
- Implementers
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asBlob(
) → Expr< Uint8List?> -
Available on Expr<
Cast as Expr<Uint8List?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BLOB). -
asBool(
) → Expr< bool?> -
Available on Expr<
Cast as Expr<bool?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BOOLEAN). -
asBool(
) → Expr< bool?> -
Available on Expr<
Extract the value as unquoted text and cast it to a boolean.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asDateTime(
) → Expr< DateTime?> -
Available on Expr<
Cast as Expr<DateTime?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS TIMESTAMP). -
asDouble(
) → Expr< double?> -
Available on Expr<
Cast as Expr<double?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS DOUBLE PRECISION). -
asDouble(
) → Expr< double?> -
Available on Expr<
Extract the value as unquoted text and cast it to a double.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asInt(
) → Expr< int?> -
Available on Expr<
Cast as Expr<int?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS BIGINT). -
asInt(
) → Expr< int?> -
Available on Expr<
Extract the value as unquoted text and cast it to an integer.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asJsonValue(
) → Expr< JsonValue?> -
Available on Expr<
Cast as Expr<JsonValue?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS JSONB). -
asString(
) → Expr< String?> -
Available on Expr<
Cast as Expr<String?> usingNull> , provided by the ExpressionNull extensionCAST(NULL AS TEXT). -
asString(
) → Expr< String?> -
Available on Expr<
Extract the value as unquoted text.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
elementAt(
int index) → Expr< JsonValue?> -
Available on Expr<
Access an index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
field(
String key) → Expr< JsonValue?> -
Available on Expr<
Access a key in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orElse(
Expr< JsonValue> value) → Expr<JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead. -
orElseValue(
JsonValue value) → Expr< JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object keyOrIndex) → Expr< JsonValue?> -
Available on Expr<
Access a key or index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension