ExpressionNullableJsonValue extension
Extension methods for nullable JsonValue expressions.
Methods
-
asBool(
) → Expr< bool?> -
Available on Expr<
Extract the value as unquoted text and cast it to a boolean.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asDouble(
) → Expr< double?> -
Available on Expr<
Extract the value as unquoted text and cast it to a double.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asInt(
) → Expr< int?> -
Available on Expr<
Extract the value as unquoted text and cast it to an integer.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
asString(
) → Expr< String?> -
Available on Expr<
Extract the value as unquoted text.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
elementAt(
int index) → Expr< JsonValue?> -
Available on Expr<
Access an index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
field(
String key) → Expr< JsonValue?> -
Available on Expr<
Access a key in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension -
isNotNull(
) → Expr< bool> -
Available on Expr<
Check if this expression is notJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
isNull(
) → Expr< bool> -
Available on Expr<
Check if this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL. -
orElse(
Expr< JsonValue> value) → Expr<JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead. -
orElseValue(
JsonValue value) → Expr< JsonValue> -
Available on Expr<
If this expression isJsonValue?> , provided by the ExpressionNullableJsonValue extensionNULL, usevalueinstead.
Operators
-
operator [](
Object keyOrIndex) → Expr< JsonValue?> -
Available on Expr<
Access a key or index in this JSON value.JsonValue?> , provided by the ExpressionNullableJsonValue extension