except method
Combine this Query with other using EXCEPT set operator.
This returns a Query containing all the rows that appear in this
Query and does not appear in other, with duplicate rows appearing
only once.
Implementation
Query<(Expr<A>, Expr<B>, Expr<C>, Expr<D>)> except(
Query<(Expr<A>, Expr<B>, Expr<C>, Expr<D>)> other,
) => Query._(
_context,
_expressions,
(e) => ExceptClause._(_from(_expressions.toList()), other._castAs(this)),
);