join<T extends Record> method
InnerJoin<(Expr<A> , Expr<B> , Expr<C> , Expr<D> , Expr<E> , Expr<F> ), T>
join<T extends Record>(
- Query<
T> query
Join this Query with another Query using INNER JOIN clause.
This method returns an InnerJoin object on which you must call either
.allto get the cartesian product of the two queries, or,.onto specify how the two queries should be joined.
This always creates a INNER JOIN, where the .on condition can be
used to control how the two queries are joined.
Implementation
InnerJoin<(Expr<A>, Expr<B>, Expr<C>, Expr<D>, Expr<E>, Expr<F>), T>
join<T extends Record>(Query<T> query) => InnerJoin._(this, query);